This directory contains files required to support POSIX-compatible OSes, like GNU/Linux, OS X or BSD.  

Common files are placed in this directory directly.  
SDL backend files are in `sdl` subdirectory.  
Native OS X backend files are in `cocoa` subdirectory.  
Shared files for both OS X backends are in `osx` subdirectory.
